Index: src/crankshaft/ppc/lithium-codegen-ppc.cc |
diff --git a/src/crankshaft/ppc/lithium-codegen-ppc.cc b/src/crankshaft/ppc/lithium-codegen-ppc.cc |
index 4aaa0cb0f95620b01d36c0dee37c79d8b2e0f414..0db7ad5018b1ee13ae52bc750a15e97faa43f7d0 100644 |
--- a/src/crankshaft/ppc/lithium-codegen-ppc.cc |
+++ b/src/crankshaft/ppc/lithium-codegen-ppc.cc |
@@ -3046,11 +3046,11 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ bne(&done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
__ LoadP(result, FieldMemOperand(result, Cell::kValueOffset)); |
- __ CmpSmiLiteral(result, Smi::FromInt(Isolate::kArrayProtectorValid), r0); |
+ __ CmpSmiLiteral(result, Smi::FromInt(Isolate::kProtectorValid), r0); |
DeoptimizeIf(ne, instr, DeoptimizeReason::kHole); |
} |
__ LoadRoot(result, Heap::kUndefinedValueRootIndex); |
@@ -3046,11 +3046,11 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |